@@ -11,7 +11,7 @@ use Carp();
 use POSIX();
 use Config;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub _USER_READ_WRITE_PERMISSIONS         { return 600 }
 sub _USER_READ_WRITE_EXECUTE_PERMISSIONS { return 700 }
@@ -215,7 +215,7 @@ Test::Rsyslog - Creates a temporary instance of rsyslog to run tests against
 
 =head1 VERSION
 
-Version 0.03
+Version 0.05
 
 =head1 SYNOPSIS
  
@@ -227,9 +227,7 @@ Version 0.03
   Sys::Syslog::syslog('info|LOG_LOCAL7','This is a test message');
   Sys::Syslog::closelog();
 
-  $rsyslog->stop(); # Flush messages to the disk
   ok($rsyslog->find('This is a test message'), 'Rsyslog is okay');
-  $rsyslog->start(); # Ready for the next test
  
 =head1 DESCRIPTION
 
@@ -322,7 +320,7 @@ Test::Rsyslog requires no configuration files or environment variables.
  
 =head1 DEPENDENCIES
  
-Test::Rsyslog requires Perl 5.10 or better.
+Test::Rsyslog requires Perl 5.6 or better.
  
 =head1 INCOMPATIBILITIES
  
